@@ -3,7 +3,9 @@ import json
 from pprint import pprint
 
 class Wiggle:
-    def __init__(self, host, user, pw, token):
+    def __init__(self):
+        self
+    def init(self, host, user, pw, token):
 	self.host = host
         self.headers = {"Content-type": "application/json;charset=UTF-8",
                         "Accept": "application/json"}
@@ -105,15 +107,17 @@ class Wiggle:
         if (response.status == 303):
             newurl = response.getheader('Location')
             conn = self.conn()
-            conn.request("POST", newurl,  json.dumps(body), self.headers)
+            conn.request("GET", newurl, "", self.headers)
             response = conn.getresponse()
             if (response.status != 200):
+                print response.status
                 return False
             else:
                 return json.loads(response.read())
         elif (response.status == 200):
             return json.loads(response.read())
         else:
+            print response.status
             return False
 
     def list(self, resource):
@@ -149,27 +153,36 @@ class Entity:
     def __init__(self, wiggle):
         self._resource = "none"
         self._wiggle = wiggle
+
     def _put(self, uuid, body):
         return self._wiggle.put(self._resource, uuid, body)
-    def _post(self, uuid, body):
-        return self._wiggle.post(self._resource, uuid, body)
+
+    def _post(self, body):
+        return self._wiggle.post(self._resource, body)
+
     def _post_attr(self, uuid, entity, body):
         return self._wiggle.post_attr(self._resource, uuid, entity, body)
+
     def _put_attr(self, uuid, entity, body):
         return self._wiggle.put_attr(self._resource, uuid, entity, body)
-    def _delete_attr(self, uuid, attr):
-        return self._wiggle.delete_attr(self._resource, uuid, attr)
+
     def _get_attr(self, uuid, attr):
         return self._wiggle.get_attr(self._resource, uuid, attr)
+
     def list(self):
         return self._wiggle.list(self._resource)
+
     def get(self, uuid):
         return self._wiggle.get(self._resource, uuid)
+
     def delete(self, uuid):
         return self._wiggle.delete(self._resource, uuid)
+
     def get_metadata(self, uuid):
         return self._wiggle.get_attr(self._resource, uuid, "metadata")
+
     def set_metadata(self, uuid, path, k, v):
         return self._wiggle.put(self._resource, uuid, "metadata" + path , {k: v})
+
     def delete_metadata(self, uuid, path, k):
         return self._wiggle.put(self._resource, uuid, "metadata" + path, {k: v})
